@@ -5,7 +5,7 @@
 #################################################################
 
 #Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-#Version: 0.1.0-9
+#Version: 0.2.0-2
 
 import os
 import sys
@@ -105,21 +105,21 @@ class MyMainWindow(QtGui.QMainWindow):
         ##Create Methods
                 
         def doAbout(self):
-             msg = "The swappolube editor is a user interface to the configuration of the swappolube method.\n"
-             msg += "It provides the ability to edit several kernel settings as described in: http://talk.maemo.org/showthread.php?t=62312\n"
-             msg += "See also http://wiki.maemo.org/Swappolube"
-             QMessageBox.about(self, "About - swappolube editor", msg)
+             msg = "The SWAPPOLUBE Editor is a user interface to the configuration of several parameters of the N900 kernel with the aim to make it faster.\n"
+             msg += "It provides the ability to change a number of parameters while in operation and if chosen will make them persistent by adding a script to event.d to set them after each boot.\n"
+             msg += "Additional information could be found in http://wiki.maemo.org/Swappolube"
+             QMessageBox.about(self, "About - SWAPPOLUBE editor", msg)
 
         def doCredits(self):
              msg = unichr(int('00A9', 16)) + "2010, Christos Zamantzas (saturn)\n"
              msg += unichr(int('00A9', 16)) + "2010, Ernesto de Bernardis (debernardis)\n\n"
-             msg += "Configuration Interface for the swappolube method\n"
+             msg += "Configuration Interface for several kernel parameters\n"
              msg += "Distributed under GPL ver. 2"
-             QMessageBox.about(self, "Credits - swappolube editor", msg)
+             QMessageBox.about(self, "Credits - SWAPPOLUBE Editor", msg)
  
         def doDeleteTunings(self):
              os.system('echo "rm /etc/event.d/tuning"|root')
-             message = 'The tuning file has been removed from the event.d folder.\n On next reboot the system will start with its defauld configuration.'
+             message = 'The tuning file has been removed from the boot sequence.\nOn next reboot, the system will start with its default configuration.'
              showMessage(message)
 
         def doSetCurrent(self):
@@ -145,11 +145,6 @@ class MyMainWindow(QtGui.QMainWindow):
              else:
                 self.ui.checkBoxKillAllocatingTask.setChecked(False)
 
-             if os.popen('cat /proc/sys/vm/laptop_mode').read() == '1\n':
-               self.ui.checkBoxLaptopMode.setChecked(True)
-             else:
-               self.ui.checkBoxLaptopMode.setChecked(False)
-
              if os.popen('cat /proc/sys/net/ipv4/tcp_timestamps').read() == '1\n':
                self.ui.checkBoxTCPTimestamps.setChecked(True)
              else:
@@ -161,6 +156,7 @@ class MyMainWindow(QtGui.QMainWindow):
                self.ui.checkBoxTCPNoMetricsSave.setChecked(False)
 
              ##Set values for lineEdits
+             LaptopMode = os.popen('cat /proc/sys/vm/laptop_mode').read()
              DirtyRatio = os.popen('cat /proc/sys/vm/dirty_ratio').read()
              Swappiness = os.popen('cat /proc/sys/vm/swappiness').read()
              DirtyBGDRatio = os.popen('cat /proc/sys/vm/dirty_background_ratio').read()
@@ -169,6 +165,7 @@ class MyMainWindow(QtGui.QMainWindow):
              DirtyWritebackCentisecs = os.popen('cat /proc/sys/vm/dirty_writeback_centisecs').read()
              DirtyExpireCentisecs = os.popen('cat /proc/sys/vm/dirty_expire_centisecs').read()
              
+             self.ui.lineLaptopMode.setText("%s" % LaptopMode)
              self.ui.lineDirtyRatio.setText("%s" % DirtyRatio)
              self.ui.lineSwappiness.setText("%s" % Swappiness)
              self.ui.lineDirtyBGDRatio.setText("%s" % DirtyBGDRatio)  
@@ -198,11 +195,11 @@ class MyMainWindow(QtGui.QMainWindow):
 
              ##Set Values for checkboxes
              self.ui.checkBoxKillAllocatingTask.setChecked(True)
-             self.ui.checkBoxLaptopMode.setChecked(True)
              self.ui.checkBoxTCPTimestamps.setChecked(False)
              self.ui.checkBoxTCPNoMetricsSave.setChecked(True)
 
              ##Set values for lineEdits
+             self.ui.lineLaptopMode.setText("1")
              self.ui.lineDirtyRatio.setText("95")
              self.ui.lineSwappiness.setText("30")
              self.ui.lineDirtyBGDRatio.setText("60")  
@@ -226,15 +223,12 @@ class MyMainWindow(QtGui.QMainWindow):
              PageCluster = self.ui.linePageCluster.text()
              DirtyExpireCentisecs = self.ui.lineDirtyExpireCentisecs.text()
              DirtyWritebackCentisecs = self.ui.lineDirtyWritebackCentisecs.text()
+             LaptopMode = self.ui.lineLaptopMode.text()
                 
              if  self.ui.checkBoxKillAllocatingTask.isChecked() == True:
                 KillAllocatingTask = '1'
              else:
                 KillAllocatingTask = '0'
-             if self.ui.checkBoxLaptopMode.isChecked() == True:
-                LaptopMode = '1'
-             else:
-                LaptopMode = '0'
              if self.ui.checkBoxTCPTimestamps.isChecked() == True:
                 TCPTimestamps = '1'
              else:
@@ -282,15 +276,12 @@ class MyMainWindow(QtGui.QMainWindow):
              DirtyExpireCentisecs = self.ui.lineDirtyExpireCentisecs.text()
              DirtyWritebackCentisecs = self.ui.lineDirtyWritebackCentisecs.text()
              VFSCachePressure = self.ui.lineVFSCachePressure.text()
-                
+             LaptopMode = self.ui.lineLaptopMode.text()
+
              if  self.ui.checkBoxKillAllocatingTask.isChecked() == True:
                 KillAllocatingTask = '1'
              else:
                 KillAllocatingTask = '0'
-             if self.ui.checkBoxLaptopMode.isChecked() == True:
-                LaptopMode = '1'
-             else:
-                LaptopMode = '0'
              if self.ui.checkBoxTCPTimestamps.isChecked() == True:
                 TCPTimestamps = '1'
              else:
